-- FUNCTION: public.logRegPredict(double precision[], double precision[])

-- DROP FUNCTION public."logRegPredict"(double precision[], double precision[]);

CREATE OR REPLACE FUNCTION public."logRegPredict"(
	inputs double precision[],
	coefficients double precision[])
    RETURNS double precision
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE PARALLEL UNSAFE
AS $BODY$
declare
	yPredict double precision := coefficients[1];
	i integer := 1;
	loopLimit integer := array_length(inputs, 1);
begin
	loop
		exit when i = loopLimit;
		yPredict := yPredict + coefficients[i + 1] * inputs[i];
		i := i + 1;
	end loop;
	return (1.0 / (1.0 + exp(-yPredict)));
end;
$BODY$;

ALTER FUNCTION public."logRegPredict"(double precision[], double precision[])
    OWNER TO postgres;

COMMENT ON FUNCTION public."logRegPredict"(double precision[], double precision[])
    IS 'Predicts a logistic regression with given coef and arguments';
